pub struct Browser { /* private fields */ }Expand description
Browser session for managing CDP connections
Implementations
Sourceimpl Browser
impl Browser
Sourcepub fn new(profile: BrowserProfile) -> Self
pub fn new(profile: BrowserProfile) -> Self
Create a new Browser session with given profile
Sourcepub fn with_cdp_url(self, cdp_url: String) -> Self
pub fn with_cdp_url(self, cdp_url: String) -> Self
Set CDP URL to connect to existing browser instead of launching new one
Sourcepub async fn start(&mut self) -> Result<()>
pub async fn start(&mut self) -> Result<()>
Start the browser session (launches browser or connects to existing)
Navigate to the specified URL
Sourcepub async fn get_current_url(&self) -> Result<String>
pub async fn get_current_url(&self) -> Result<String>
Get the current page URL
Sourcepub async fn stop(&mut self) -> Result<()>
pub async fn stop(&mut self) -> Result<()>
Stop the browser session and clean up resources
Safety Policy
IMPORTANT: This method does NOT delete browser data directories.
We never cleanup user data for safety reasons:
- Users may specify a custom
user_data_dirpointing to their real browser profile - Deleting user data (bookmarks, history, passwords, extensions) would be catastrophic
- Temporary profiles are preserved for debugging and inspection
Users are responsible for managing their own browser data directories.
Sourcepub fn get_cdp_client(&self) -> Result<Arc<CdpClient>>
pub fn get_cdp_client(&self) -> Result<Arc<CdpClient>>
Get the CDP client for the current session
Sourcepub fn get_session_id(&self) -> Result<String>
pub fn get_session_id(&self) -> Result<String>
Get the session ID for the current target
Sourcepub fn get_current_target_id(&self) -> Result<String>
pub fn get_current_target_id(&self) -> Result<String>
Get the current target ID
Sourcepub async fn take_screenshot(
&self,
path: Option<&str>,
full_page: bool,
format: Option<&str>,
quality: Option<u32>,
) -> Result<Vec<u8>>
pub async fn take_screenshot( &self, path: Option<&str>, full_page: bool, format: Option<&str>, quality: Option<u32>, ) -> Result<Vec<u8>>
Take a screenshot of the current page
Sourcepub async fn switch_to_tab(&mut self, target_id: &str) -> Result<()>
pub async fn switch_to_tab(&mut self, target_id: &str) -> Result<()>
Switch to a different tab by target ID
Sourcepub async fn get_target_id_from_tab_id(&self, tab_id: &str) -> Result<String>
pub async fn get_target_id_from_tab_id(&self, tab_id: &str) -> Result<String>
Get target ID from short tab ID (last 4 characters)
Sourcepub async fn get_current_page_title(&self) -> Result<String>
pub async fn get_current_page_title(&self) -> Result<String>
Get the current page title
Sourcepub async fn get_browser_state_summary(
&self,
include_screenshot: bool,
dom_service: Option<&DomService>,
) -> Result<BrowserStateSummary>
pub async fn get_browser_state_summary( &self, include_screenshot: bool, dom_service: Option<&DomService>, ) -> Result<BrowserStateSummary>
Get browser state summary for LLM consumption